@@ -94,17 +94,18 @@ Window make_ident_window();
 void fill_window_data();
 void display_window_data();
 void add_property( const char *name, const char *value, unsigned long value_encoding, Bool span_cols );
-
+void DeadPipe(int);
 
 int
 main( int argc, char **argv )
 {
     /* Save our program name - for error messages */
+	set_DeadPipe_handler(DeadPipe);
     InitMyApp (CLASS_IDENT, argc, argv, NULL, NULL, 0 );
 
     set_signal_handler( SIGSEGV );
 
-    ConnectX( &Scr, 0 );
+    ConnectX( ASDefaultScr, 0 );
     ConnectAfterStep (WINDOW_CONFIG_MASK |
                       WINDOW_NAME_MASK |
                       M_END_WINDOWLIST);
@@ -391,7 +392,7 @@ make_ident_window( int width, int height)
 	shints.win_gravity = Config->gravity ;
 
 	extwm_hints.pid = getpid();
-    extwm_hints.flags = EXTWM_PID ;
+    extwm_hints.flags = EXTWM_PID|EXTWM_TypeASModule ;
 
 	set_client_hints( w, NULL, &shints, AS_DoesWmDeleteWindow, &extwm_hints );
 
@@ -578,10 +579,11 @@ fill_window_data()
 	SHOW_FLAG(wd->flags,SizeInc);
 	SHOW_FLAG(wd->flags,BaseSize);
 	SHOW_FLAG(wd->flags,Gravity);
+	SHOW_FLAG(wd->flags,Module);
 	
 	add_property("Specified hint values:", buf, AS_Text_ASCII, True);
 
-    if( collect_hints( &Scr, wd->client, HINT_ANY, &raw ) )
+    if( collect_hints( ASDefaultScr, wd->client, HINT_ANY, &raw ) )
 	{
 		ExtendedWMHints *eh = &(raw.extwm_hints);
 		GnomeHints *gh = &(raw.gnome_hints);
