@@ -119,17 +119,18 @@ void press_tab( int tab );
 void set_tab_look( ASWinTab *aswt );
 
 unsigned int find_tab_by_position( int root_x, int root_y );
-
+void DeadPipe(int);
 
 int
 main( int argc, char **argv )
 {
     /* Save our program name - for error messages */
+	set_DeadPipe_handler(DeadPipe);
     InitMyApp (CLASS_GADGET, argc, argv, NULL, NULL, 0 );
     set_signal_handler( SIGSEGV );
 
 
-    ConnectX( &Scr, PropertyChangeMask|EnterWindowMask );
+    ConnectX( ASDefaultScr, PropertyChangeMask|EnterWindowMask );
     ConnectAfterStep (  M_END_WINDOWLIST |
                         M_DESTROY_WINDOW |
                     	WINDOW_CONFIG_MASK |
@@ -579,7 +580,7 @@ make_wintabs_window()
     shints.win_gravity = Config->gravity ;
 
 	extwm_hints.pid = getpid();
-    extwm_hints.flags = EXTWM_PID|EXTWM_StateSkipTaskbar|EXTWM_StateSkipPager ;
+    extwm_hints.flags = EXTWM_PID|EXTWM_StateSkipTaskbar|EXTWM_StateSkipPager|EXTWM_TypeASModule ;
 
 	set_client_hints( w, NULL, &shints, AS_DoesWmDeleteWindow, &extwm_hints );
 
