@@ -886,19 +886,15 @@ hints2decorations( ASWindow *asw, ASHints *old_hints )
 
 	LOCAL_DEBUG_CALLER_OUT( "asw(%p)->client(%lX)", asw, asw?asw->w:0 );
 
-	if( old_hints == NULL || get_flags(old_hints->flags, AS_Icon) != ASWIN_HFLAGS( asw, AS_Icon) )
-	{	/* 3) we need to prepare icon window : */
-    	check_icon_canvas( asw, (ASWIN_HFLAGS( asw, AS_Icon) && !get_flags(Scr.Feel.flags, SuppressIcons)) );
-	}
+	/* 3) we need to prepare icon window : */
+    check_icon_canvas( asw, (ASWIN_HFLAGS( asw, AS_Icon) && !get_flags(Scr.Feel.flags, SuppressIcons)) );
 
-	if( old_hints == NULL || get_flags(old_hints->flags, AS_IconTitle|AS_Icon) != ASWIN_HFLAGS( asw, AS_IconTitle|AS_Icon) )
-	{/* 4) we need to prepare icon title window : */
-	    check_icon_title_canvas( asw, (ASWIN_HFLAGS( asw, AS_IconTitle) &&
-    	                               get_flags(Scr.Feel.flags, IconTitle) &&
-        	                          !get_flags(Scr.Feel.flags, SuppressIcons)),
-            	                      !get_flags(Scr.Look.flags, SeparateButtonTitle)&&
-                	                  (asw->icon_canvas!=NULL) );
-	}
+	/* 4) we need to prepare icon title window : */
+	check_icon_title_canvas( asw, (ASWIN_HFLAGS( asw, AS_IconTitle) &&
+                                   get_flags(Scr.Feel.flags, IconTitle) &&
+       	                          !get_flags(Scr.Feel.flags, SuppressIcons)),
+           	                      !get_flags(Scr.Look.flags, SeparateButtonTitle)&&
+               	                  (asw->icon_canvas!=NULL) );
 
     has_tbar = (ASWIN_HFLAGS(asw, AS_Titlebar)!= 0);
 	frame = myframe_find( ASWIN_HFLAGS(asw, AS_Frame)?asw->hints->frame_name:NULL );
@@ -978,15 +974,14 @@ hints2decorations( ASWindow *asw, ASHints *old_hints )
     }
 
     /* 7) now we have to create bar for icon title (optional) */
-	if( asw->icon_title == NULL &&
-		(asw->icon_canvas != NULL||asw->icon_title_canvas != NULL) )
-	{
-		check_tbar( &(asw->icon_title), (asw->icon_canvas != NULL||asw->icon_title_canvas != NULL), AS_ICON_TITLE_MYSTYLE,
-  	            	NULL, 0, 0, 0, ALIGN_CENTER, DEFAULT_TBAR_HILITE, DEFAULT_TBAR_HILITE,
-              		TEXTURE_TRANSPIXMAP_ALPHA, TEXTURE_TRANSPIXMAP_ALPHA,
-              		C_IconTitle );
-	}
-    if( asw->icon_title )
+	check_tbar( &(asw->icon_title), 
+			    get_flags(Scr.Feel.flags, IconTitle) && ((asw->icon_canvas != NULL && !get_flags(Scr.Look.flags, SeparateButtonTitle)) || asw->icon_title_canvas != NULL), 
+				AS_ICON_TITLE_MYSTYLE,
+  	            NULL, 0, 0, 0, ALIGN_CENTER, DEFAULT_TBAR_HILITE, DEFAULT_TBAR_HILITE,
+              	TEXTURE_TRANSPIXMAP_ALPHA, TEXTURE_TRANSPIXMAP_ALPHA,
+              	C_IconTitle );
+    
+	if( asw->icon_title )
     {
 		if( add_icon_label )
 		{
@@ -1080,6 +1075,12 @@ hints2decorations( ASWindow *asw, ASHints *old_hints )
                 	frame->title_fbevel, frame->title_ubevel,
                 	frame->title_fcm, frame->title_ucm,
                 	C_TITLE );
+		if( asw->tbar ) 
+		{	
+			set_astbar_huesat( asw->tbar, BAR_STATE_FOCUSED, frame->title_fhue, frame->title_fsat );
+			set_astbar_huesat( asw->tbar, BAR_STATE_UNFOCUSED, frame->title_uhue, frame->title_usat );
+		}
+
 		tbar_created = (asw->tbar != NULL);
 	}
 
@@ -1209,7 +1210,7 @@ hints2decorations( ASWindow *asw, ASHints *old_hints )
 	        add_astbar_btnblock(asw->tbar,
   		                        tbar_layout_col[ASO_TBAR_ELEM_LBTN],
       		                    tbar_layout_row[ASO_TBAR_ELEM_LBTN],
-                                od->flip, ALIGN_VCENTER,
+                                od->flip, frame->left_btn_align,
               		            &(Scr.Look.ordered_buttons[0]), btn_mask,
                   		        Scr.Look.button_first_right,
                       		    Scr.Look.TitleButtonXOffset[0], Scr.Look.TitleButtonYOffset[0], Scr.Look.TitleButtonSpacing[0],
@@ -1219,7 +1220,7 @@ hints2decorations( ASWindow *asw, ASHints *old_hints )
   		    add_astbar_btnblock(asw->tbar,
       		                    tbar_layout_col[ASO_TBAR_ELEM_RBTN],
           		                tbar_layout_row[ASO_TBAR_ELEM_RBTN],
-                                od->flip, ALIGN_VCENTER,
+                                od->flip, frame->right_btn_align,
                   		        &(Scr.Look.ordered_buttons[Scr.Look.button_first_right]), btn_mask,
                       		    TITLE_BUTTONS - Scr.Look.button_first_right,
                           		Scr.Look.TitleButtonXOffset[1], Scr.Look.TitleButtonYOffset[1], Scr.Look.TitleButtonSpacing[1],
